@@ -1,9 +1,9 @@
 import json
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.mapping.kgtk import create_kgtk
-
 from t2wml.wikification.item_table import Wikifier
 from t2wml.spreadsheets.sheet import Sheet
+from t2wml.spreadsheets.conversions import to_excel
 from t2wml.mapping.statement_mapper import YamlMapper, StatementMapper
 from t2wml.mapping.canonical_spreadsheet import create_canonical_spreadsheet
 
@@ -27,29 +27,9 @@ class KnowledgeGraph:
         self.metadata = metadata or {}
         self.sheet = sheet
 
-    @classmethod
-    def load_json(cls, filename: str):
-        """load a KnowledgeGraph instance from a saved json file.
-
-        Args:
-            filename (str): location of the json file
-
-        Returns:
-            KnowledgeGraph: an initialized KnowledgeGraph instance
-        """
-        with open(filename, 'r', encoding="utf-8") as f:
-            loaded = json.load(f)
-        statements = loaded["statements"]
-        errors = loaded.get("errors", [])
-        metadata = loaded.get("metadata", {})
-        sheet=loaded.get("sheet", None)
-        if sheet:
-            sheet=Sheet.from_json(sheet)
-        return cls(statements, errors, metadata, sheet)
-
     @classmethod
     def get_single_cell(cls, statement_mapper:StatementMapper, sheet:Sheet, wikifier:Wikifier, row:int, col:int):
-        statement, errors = statement_mapper.get_cell_statement(sheet, wikifier, col, row, do_init=True)
+        statement, errors = statement_mapper.get_cell_statement(col, row, True, sheet, wikifier)
 
     @classmethod
     def generate(cls, statement_mapper:StatementMapper, sheet:Sheet, wikifier:Wikifier, start=0, end=None, count=None):
@@ -100,7 +80,8 @@ class KnowledgeGraph:
 
         if filetype == 'json':
             # insertion-ordered
-            output = json.dumps(self.statements, indent=3, sort_keys=False)
+            json_compatible_dict = {to_excel(*key):self.statements[key] for key in self.statements}
+            output = json.dumps(json_compatible_dict, indent=3, sort_keys=False)
         elif filetype in ["kgtk", "tsv"]:
             output = create_kgtk(self.statements, file_path, sheet_name, project=project)
         elif filetype == "csv":
