@@ -1,6 +1,7 @@
 
 import re
 import datetime
+from t2wml.input_processing.utils import clean_id
 
 #translate from lower-case (case insensitive) OR from wikidata standard OR for full uppercase URL, to wikidata standard
 wikidata_sparql_to_wikidata = {
@@ -39,19 +40,6 @@ wikidata_to_datamart = {
 }
 
 
-def clean_id(input):
-    '''
-    remove non alphanumeric characters and lowercase
-    replace whitespace by _ (underscore)
-    '''
-    output = str(input)
-    output = re.sub(r'[^A-Za-z0-9\s]+', '', output)
-    output = output.strip()
-    output = re.sub(r"\s", "_", output)
-    output = output.lower()
-    if not output:
-        raise ValueError(f"Cleaning {input} returned useless result")
-    return output
 
 def clean_name(input):
     input = input.strip()
