@@ -1,4 +1,6 @@
-from t2wml.wikification.item_table import convert_old_wikifier_to_new
+import json
+from typing import DefaultDict
+from t2wml.wikification.item_table import Wikifier, convert_old_df_to_dict, convert_old_wikifier_to_new
 from t2wml.mapping.datamart_edges import clean_id
 import yaml
 import os
@@ -14,7 +16,7 @@ from t2wml.utils.debug_logging import basic_debug
 
 
 class Project:
-    @basic_debug
+    #@basic_debug
     def __init__(self, directory, title=None, description="", url="",
                     data_files=None, yaml_files=None, entity_files=None, wikifier_files=None,
                     yaml_sheet_associations=None, annotations=None,
@@ -53,6 +55,7 @@ class Project:
         if not os.path.isdir(os.path.join(self.directory, "wikifiers")):
             os.mkdir(os.path.join(self.directory, "wikifiers"))
         
+        #backwards compatibility 1 (<0.5.0)
         if wikifier_files:
             warnings.warn("wikifier files are being removed from project", DeprecationWarning)
             for wf in wikifier_files:
@@ -60,11 +63,57 @@ class Project:
                 wf_path = self.get_full_path(wf)
                 self.add_old_style_wikifier_to_project(wf_path)
             self.save()
+        
+        #backwards comptibility 2 (<0.6.3)
+        wikifier_dir=os.path.join(self.directory, "wikifiers")
+        if os.path.exists(wikifier_dir):
+            expected_filenames_with_ext = set([clean_id(filename)+".json" for filename in self.data_files])
+            expected_filenames_without_ext = {clean_id(filename):filename for filename in self.data_files}
+            problem_filenames=[]
+            for filename in os.listdir(wikifier_dir):
+                if filename not in expected_filenames_with_ext:
+                    problem_filenames.append(filename)
+            
+            corrected_filenames=DefaultDict(list)
+
+            for problem in problem_filenames:
+                for key in expected_filenames_without_ext:
+                    if key in problem:
+                        proper_name = expected_filenames_without_ext[key]
+                        corrected_filenames[proper_name].append(problem)
+            
+            for actual_file_path in corrected_filenames:
+                problem_arr=corrected_filenames[actual_file_path]
+                wikifier_file_path, exists=self.get_wikifier_file(actual_file_path)
+                wikifier = Wikifier(filepath=wikifier_file_path)
+                for problem_file in problem_arr:
+                    if Path(problem_file).suffix==".json":
+                        with open(os.path.join(wikifier_dir, problem_file), 'r') as f:
+                            wiki_dict=json.load(f)
+                        wikifier.update_from_dict(wiki_dict)
+                    elif Path(problem_file).suffix==".csv":
+                        df = pd.read_csv(os.path.join(wikifier_dir, problem_file))
+                        wiki_dict = convert_old_df_to_dict(df)
+                        wikifier.update_from_dict(wiki_dict)
+
+                    wikifier.save_to_file(wikifier_file_path)
+            
+            for problem_file in problem_filenames:
+                try:
+                    os.remove(os.path.join(wikifier_dir, problem_file))
+                except Exception as e:
+                    print(e)
+
+
+
+
+
+
 
     
     @property
     def autogen_dir(self):
-        auto= os.path.join(self.directory, "annotations", f"autogen-files-{self.dataset_id}")
+        auto= os.path.join(self.directory, "annotations", f"autogen-files")
         if not os.path.exists(auto):
             os.makedirs(auto, exist_ok=True)
         return auto
@@ -77,7 +126,7 @@ class Project:
     def dataset_id(self):
         return clean_id(self.title)
 
-    @basic_debug
+    #@basic_debug
     def _add_file(self, file_path, copy_from_elsewhere=False, overwrite=False, rename=False):
         if os.path.isabs(file_path):
             root=Path(self.directory)
@@ -187,7 +236,7 @@ class Project:
             self.annotations[data_path]={sheet_name:dict(val_arr=[annotation_path], selected=annotation_path)}
         return annotation_path
 
-    @basic_debug
+    #@basic_debug
     def _normalize_path(self, file_path):
         root=Path(self.directory)
         full_path=Path(file_path)
@@ -214,28 +263,28 @@ class Project:
                     return True
         return False
     
-    def get_wikifier_file(self, data_file_path):
-        data_file_path=self._normalize_path(data_file_path)
-        wikifier_name=clean_id(data_file_path) + ".csv"
+    def get_wikifier_file(self, file_path):
+        data_file_path=self._normalize_path(file_path)
+        wikifier_name=clean_id(data_file_path) + ".json"
         wikifier_file_path=os.path.join(self.directory, "wikifiers", wikifier_name)
         if os.path.exists(wikifier_file_path):
             return wikifier_file_path, True
         return wikifier_file_path, False
     
-    def add_df_to_wikifier_file(self, data_file_path, df, overwrite_existing=False):
-        wikifier_file_path, exists=self.get_wikifier_file(data_file_path)
+    def add_dict_to_wikifier_file(self, sheet, wiki_dict, overwrite_existing=True):
+        wikifier_file_path, exists=self.get_wikifier_file(sheet.data_file_path)
         if exists:
-            #clear any clashes/duplicates
-            org_df=pd.read_csv(wikifier_file_path)
-            keep='first'
-            if overwrite_existing:
-                keep='last'
-            combined_df = pd.concat([org_df, df])
-            df=combined_df.drop_duplicates(subset=['row', 'column', 'value', 'file', 'sheet', 'context'], keep=keep).reset_index(drop=True)
-        df.to_csv(wikifier_file_path, index=False, escapechar="")
-        return df
+            wikifier = Wikifier.load_from_file(wikifier_file_path)
+        else:
+            wikifier = Wikifier(filepath=wikifier_file_path)
+        wikifier.update_from_dict(wiki_dict, overwrite_existing)
+        wikifier.save_to_file(wikifier_file_path)
+    
+    def add_df_to_wikifier_file(self, sheet, df, overwrite_existing=True):
+        wiki_dict = convert_old_df_to_dict(df)
+        self.add_dict_to_wikifier_file(sheet, wiki_dict, overwrite_existing)
 
-    @basic_debug
+    #@basic_debug
     def delete_file_from_project(self, file_path, delete_from_fs=False):
         if not self.path_in_files(file_path):
             raise ValueError("The file you are trying to delete does not exist in project")
@@ -284,7 +333,7 @@ class Project:
                     pass #print(e)
 
                 
-    @basic_debug
+    #@basic_debug
     def rename_file_in_project(self, old_name, new_name, rename_in_fs=False):
         old_name=self._normalize_path(old_name)
         new_name=self._normalize_path(new_name)
@@ -340,7 +389,7 @@ class Project:
                 os.rename(old_wikifier_file_path, new_wikifier_file_path)
 
         
-    @basic_debug
+    #@basic_debug
     def save(self):
         output_dict=dict(self.__dict__)
         output_dict.pop('directory')
@@ -351,7 +400,7 @@ class Project:
         return proj_file_path
 
     @classmethod
-    @basic_debug
+    #@basic_debug
     def load(cls, filepath):
         if os.path.isdir(filepath):
             filepath=os.path.join(filepath, "project.t2wml")
@@ -373,8 +422,7 @@ class Project:
     def add_old_style_wikifier_to_project(self, wikifier_file):
         for datafile in self.data_files:
             sf = SpreadsheetFile(self.get_full_path(datafile))
-            wikifier_file_path, exists = self.get_wikifier_file(datafile)
             for sheet_name in sf:
                 sheet=sf[sheet_name]
-                dataframe = convert_old_wikifier_to_new(wikifier_file, sheet)
-                self.add_df_to_wikifier_file(datafile, dataframe)
\ No newline at end of file
+                wiki_dict = convert_old_wikifier_to_new(wikifier_file, sheet)
+                self.add_dict_to_wikifier_file(sheet, wiki_dict, overwrite_existing=True)
\ No newline at end of file
