@@ -1,6 +1,5 @@
 from pathlib import Path
-import pandas as pd
-import json
+import pandas as pd   
 from t2wml.spreadsheets.utilities import PandasLoader, post_process_data
 from t2wml.spreadsheets.conversions import to_excel
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
@@ -14,7 +13,7 @@ class SpreadsheetFile(Mapping):
     All immutable dict methods are available (access by key, iteration, len, etc)
     Keys are sheet names, values are initialized Sheet instances.
     """
-    @basic_debug
+    #@basic_debug
     def __init__(self, file_path: str):
         self.file_path = file_path
         self.dict = {}
@@ -40,7 +39,7 @@ class SpreadsheetFile(Mapping):
 
 class Sheet:
     # all access to spreadsheet goes through here
-    @basic_debug
+    #@basic_debug
     def __init__(self, data_file_path: str, sheet_name: str, data=None):
         """[summary]
 
@@ -66,14 +65,30 @@ class Sheet:
         if self.cleaned_data is not None:
             return self.cleaned_data
         return self.raw_data
+    
+    @property
+    def _data_values(self): #added this property beause creating .values takes too long
+        if self.cleaned_data is not None:
+            try:
+                return self._cleaned_data_values
+            except:
+                self._cleaned_data_values = self.cleaned_data.values
+                return self._cleaned_data_values
+        else:
+            try:
+                return self._raw_data_values
+            except:
+                self._raw_data_values = self.raw_data.values
+                return self._raw_data_values
+
 
     def __getitem__(self, params):
         try:
-            return self.data.iloc[params]
+            return self._data_values[params]
         except IndexError:
             raise T2WMLExceptions.CellOutsideofBoundsException(
                 "Cell " + to_excel(params[1], params[0]) + " is outside the bounds of the current data file")
-
+    
     @property
     def row_len(self): 
         # number of rows
@@ -83,29 +98,6 @@ class Sheet:
     def col_len(self):
         # number of columns
         return self.data.shape[1]
-    
-    @basic_debug
-    def to_json(self):
-        if self.cleaned_data is not None:
-            cleaned=json.loads(self.cleaned_data.to_json(orient='values'))
-        else:
-            cleaned=None
-        return dict(cleaned=cleaned, 
-                    data=json.loads(self.data.to_json(orient='values')),
-                    data_file_path=self.data_file_path, 
-                    sheet_name=self.name)
-
-    @staticmethod
-    def from_json(in_json):
-        cleaned=in_json.pop("cleaned")
-        if cleaned:
-            cleaned=pd.DataFrame(cleaned)
-        data=in_json.pop("data")
-        if data:
-            data=pd.DataFrame(data)
-        s=Sheet(data=data, **in_json)
-        s.cleaned_data=cleaned
-        return s
 
     @classmethod
     def load_sheet_from_csv_string(cls, csv_string, data_file_path="", sheet_name="", **pandas_options):
