@@ -16,14 +16,14 @@ class TestAnnotations(unittest.TestCase):
     def test_user_link(self):
         with open(unit_test_folder/"test_annotation.annotation", 'r') as f:
             annotations=json.load(f)
-        annotations[-1]["userlink"]="9a4b3f0e-7b55-40bf-9863-b862a5216765"
+        annotations[-1]["userlink"]="0d996604-014e-4ef1-ace2-0583ecc2eb70" #"9a4b3f0e-7b55-40bf-9863-b862a5216765"
         anno=Annotation(annotations)
         anno.initialize()
-        assert anno.annotation_block_array[-1]["link"]=="9a4b3f0e-7b55-40bf-9863-b862a5216765"
+        assert anno.annotation_block_array[-1]["link"]=="0d996604-014e-4ef1-ace2-0583ecc2eb70" # "9a4b3f0e-7b55-40bf-9863-b862a5216765"
         annotations[-1]["userlink"]="nonexistentid"
         anno=Annotation(annotations)
         anno.initialize()
-        assert anno.annotation_block_array[-1]["link"]=="0d996604-014e-4ef1-ace2-0583ecc2eb70"
+        assert anno.annotation_block_array[-1]["link"]=="9a4b3f0e-7b55-40bf-9863-b862a5216765" #"0d996604-014e-4ef1-ace2-0583ecc2eb70"
 
     
 
